==> walkers-fabric-1.18.2-4.5-sources.jar: tocraft/walkers/api/model/impl/SquidEntityUpdater.java <==
package tocraft.walkers.api.model.impl;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1477;
import net.minecraft.class_1657;
import net.minecraft.class_243;
import net.minecraft.class_3532;
import tocraft.walkers.api.model.EntityUpdater;
import tocraft.walkers.mixin.accessor.SquidEntityAccessor;

@Environment(EnvType.CLIENT)
public class SquidEntityUpdater<S extends class_1477> implements EntityUpdater<S> {
    @Override
    public void update(class_1657 player, S squid) {
        squid.field_6905 = squid.field_6907;
        squid.field_6906 = squid.field_6903;
        squid.field_6902 = squid.field_6908;
        squid.field_6900 = squid.field_6904;
        squid.field_6908 += 1.0F / (squid.method_6051().nextFloat() + 1.0F) * 0.2F;
        if ((double) squid.field_6908 > 6.283185307179586) {
            squid.field_6908 = 6.2831855F;
        }

        if (player.method_5816()) {
            if (squid.field_6908 < 3.1415927F) {
                float f = squid.field_6908 / 3.1415927F;
                squid.field_6904 = class_3532.method_15374(f * f * 3.1415927F) * 3.1415927F * 0.25F;
                if ((double) f > 0.75) {
                    ((SquidEntityAccessor) squid).setSpeed(1.0F);
                    ((SquidEntityAccessor) squid).setRotateSpeed(1.0F);
                } else {
                    ((SquidEntityAccessor) squid).setRotateSpeed(((SquidEntityAccessor) squid).getRotateSpeed() * 0.8F);
                }
            } else {
                squid.field_6904 = 0.0F;
                ((SquidEntityAccessor) squid).setSpeed(((SquidEntityAccessor) squid).getSpeed() * 0.9F);
                ((SquidEntityAccessor) squid).setRotateSpeed(((SquidEntityAccessor) squid).getRotateSpeed() * 0.99F);
            }

            class_243 vec3 = player.method_18798();
            double d = vec3.method_37267();
            squid.field_6903 += 3.1415927F * ((SquidEntityAccessor) squid).getRotateSpeed() * 1.5F;
            squid.field_6907 += (-((float) class_3532.method_15349(d, vec3.field_1351)) * 57.295776F - squid.field_6907) * 0.1F;
        } else {
            squid.field_6904 = class_3532.method_15379(class_3532.method_15374(squid.field_6908)) * 3.1415927F * 0.25F;
            squid.field_6907 += (-90.0F - squid.field_6907) * 0.02F;
        }
    }
}

==> walkers-fabric-1.20.6-5.3-sources.jar: tocraft/walkers/api/model/impl/SquidEntityUpdater.java <==
package tocraft.walkers.api.model.impl;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1477;
import net.minecraft.class_1657;
import net.minecraft.class_243;
import net.minecraft.class_3532;
import tocraft.walkers.api.model.EntityUpdater;
import tocraft.walkers.mixin.accessor.SquidEntityAccessor;

@Environment(EnvType.CLIENT)
public class SquidEntityUpdater<S extends class_1477> implements EntityUpdater<S> {
    @Override
    public void update(class_1657 player, S squid) {
        squid.field_6905 = squid.field_6907;
        squid.field_6906 = squid.field_6903;
        squid.field_6902 = squid.field_6908;
        squid.field_6900 = squid.field_6904;
        squid.field_6908 += 1.0F / (squid.method_6051().method_43057() + 1.0F) * 0.2F;
        if ((double) squid.field_6908 > 6.283185307179586) {
            squid.field_6908 = 6.2831855F;
        }

        if (player.method_5816()) {
            if (squid.field_6908 < 3.1415927F) {
                float f = squid.field_6908 / 3.1415927F;
                squid.field_6904 = class_3532.method_15374(f * f * 3.1415927F) * 3.1415927F * 0.25F;
                if ((double) f > 0.75) {
                    ((SquidEntityAccessor) squid).setSpeed(1.0F);
                    ((SquidEntityAccessor) squid).setRotateSpeed(1.0F);
                } else {
                    ((SquidEntityAccessor) squid).setRotateSpeed(((SquidEntityAccessor) squid).getRotateSpeed() * 0.8F);
                }
            } else {
                squid.field_6904 = 0.0F;
                ((SquidEntityAccessor) squid).setSpeed(((SquidEntityAccessor) squid).getSpeed() * 0.9F);
                ((SquidEntityAccessor) squid).setRotateSpeed(((SquidEntityAccessor) squid).getRotateSpeed() * 0.99F);
            }

            class_243 vec3 = player.method_18798();
            double d = vec3.method_37267();
            squid.field_6903 += 3.1415927F * ((SquidEntityAccessor) squid).getRotateSpeed() * 1.5F;
            squid.field_6907 += (-((float) class_3532.method_15349(d, vec3.field_1351)) * 57.295776F - squid.field_6907) * 0.1F;
        } else {
            squid.field_6904 = class_3532.method_15379(class_3532.method_15374(squid.field_6908)) * 3.1415927F * 0.25F;
            squid.field_6907 += (-90.0F - squid.field_6907) * 0.02F;
        }
    }
}
